complete -c ouch -n "__fish_use_subcommand" -s f -l format -d 'Specify the format of the archive' -r
complete -c ouch -n "__fish_use_subcommand" -s y -l yes -d 'Skip [Y/n] questions positively'
complete -c ouch -n "__fish_use_subcommand" -s n -l no -d 'Skip [Y/n] questions negatively'
complete -c ouch -n "__fish_use_subcommand" -s A -l accessible -d 'Activate accessibility mode, reducing visual noise'
complete -c ouch -n "__fish_use_subcommand" -s H -l hidden -d 'Ignores hidden files'
complete -c ouch -n "__fish_use_subcommand" -s q -l quiet -d 'Silences output'
complete -c ouch -n "__fish_use_subcommand" -s g -l gitignore -d 'Ignores files matched by git\'s ignore files'
complete -c ouch -n "__fish_use_subcommand" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c ouch -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c ouch -n "__fish_use_subcommand" -f -a "compress" -d 'Compress one or more files into one output file'
complete -c ouch -n "__fish_use_subcommand" -f -a "decompress" -d 'Decompresses one or more files, optionally into another folder'
complete -c ouch -n "__fish_use_subcommand" -f -a "list" -d 'List contents of an archive'
complete -c ouch -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s l -l level -d 'Compression level, applied to all formats' -r
complete -c ouch -n "__fish_seen_subcommand_from compress" -s f -l format -d 'Specify the format of the archive' -r
complete -c ouch -n "__fish_seen_subcommand_from compress" -l fast -d 'Fastest compression level possible, conflicts with --level and --slow'
complete -c ouch -n "__fish_seen_subcommand_from compress" -l slow -d 'Slowest (and best) compression level possible, conflicts with --level and --fast'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s y -l yes -d 'Skip [Y/n] questions positively'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s n -l no -d 'Skip [Y/n] questions negatively'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s A -l accessible -d 'Activate accessibility mode, reducing visual noise'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s H -l hidden -d 'Ignores hidden files'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s q -l quiet -d 'Silences output'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s g -l gitignore -d 'Ignores files matched by git\'s ignore files'
complete -c ouch -n "__fish_seen_subcommand_from compress" -s h -l help -d 'Print help'
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s d -l dir -d 'Place results in a directory other than the current one' -r -F
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s f -l format -d 'Specify the format of the archive' -r
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s y -l yes -d 'Skip [Y/n] questions positively'
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s n -l no -d 'Skip [Y/n] questions negatively'
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s A -l accessible -d 'Activate accessibility mode, reducing visual noise'
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s H -l hidden -d 'Ignores hidden files'
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s q -l quiet -d 'Silences output'
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s g -l gitignore -d 'Ignores files matched by git\'s ignore files'
complete -c ouch -n "__fish_seen_subcommand_from decompress" -s h -l help -d 'Print help'
complete -c ouch -n "__fish_seen_subcommand_from list" -s f -l format -d 'Specify the format of the archive' -r
complete -c ouch -n "__fish_seen_subcommand_from list" -s t -l tree -d 'Show archive contents as a tree'
complete -c ouch -n "__fish_seen_subcommand_from list" -s y -l yes -d 'Skip [Y/n] questions positively'
complete -c ouch -n "__fish_seen_subcommand_from list" -s n -l no -d 'Skip [Y/n] questions negatively'
complete -c ouch -n "__fish_seen_subcommand_from list" -s A -l accessible -d 'Activate accessibility mode, reducing visual noise'
complete -c ouch -n "__fish_seen_subcommand_from list" -s H -l hidden -d 'Ignores hidden files'
complete -c ouch -n "__fish_seen_subcommand_from list" -s q -l quiet -d 'Silences output'
complete -c ouch -n "__fish_seen_subcommand_from list" -s g -l gitignore -d 'Ignores files matched by git\'s ignore files'
complete -c ouch -n "__fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c ouch -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from compress; and not __fish_seen_subcommand_from decompress; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "compress" -d 'Compress one or more files into one output file'
complete -c ouch -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from compress; and not __fish_seen_subcommand_from decompress; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "decompress" -d 'Decompresses one or more files, optionally into another folder'
complete -c ouch -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from compress; and not __fish_seen_subcommand_from decompress; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List contents of an archive'
complete -c ouch -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from compress; and not __fish_seen_subcommand_from decompress; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
